@@ -38,17 +38,13 @@ if (strpos(strtolower($_SERVER['PHP_SELF']), 'gf_showtopic.php') !== false) {
     die ('This file can not be used on its own.');
 }
 
-if (!defined('XHTML')) {
-    define('XHTML', '');
-}
-
 if (!function_exists( 'str_ireplace' ))
 {
     require_once 'PHP/Compat.php';
     PHP_Compat::loadFunction( 'str_ireplace' );
 }
 
-include $_CONF['path'] . 'system/lib-user.php';
+require_once $_CONF['path'] . 'system/lib-user.php';
 
 function showtopic($showtopic,$mode='',$onetwo=1,$page=1) {
     global $CONF_FORUM,$_CONF,$_TABLES,$_USER,$LANG_GF01,$LANG_GF02;
