@@ -1,5 +1,4 @@
 <?php
-
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
 // | Geeklog Forums Plugin 2.0 for Geeklog - The Ultimate Weblog               |
@@ -51,7 +50,7 @@ $LANG_GF00 = array (
     'access_denied_msg' => 'Only Root Users have Access to this Page.  Your user name and IP have been recorded.',
     'admin'             => 'Plugin Admin',
     'install_header'    => 'Install/Uninstall Plugin',
-    'installed'         => 'The Plugin and Block are now installed,<p><i>Enjoy,<br><a href="MAILTO:langmail@sympatico.ca">Blaine</a></i>',
+    'installed'         => 'The Plugin and Block are now installed,<p><i>Enjoy,<br' . XHTML . '><a href="MAILTO:langmail@sympatico.ca">Blaine</a></i>',
     'uninstalled'       => 'The Plugin is Not Installed',
     'install_success'   => 'Installation Successful<p><b>Next Steps</b>: 
         <ol><li>Use the Forum Admin to configure your new forum
@@ -63,9 +62,10 @@ $LANG_GF00 = array (
     'uninstall_msg'     => 'Plugin Successfully Uninstalled',
     'install'           => 'Install',
     'uninstall'         => 'UnInstall',
-    'enabled'           => '<br>Plugin is installed and enabled.<br>Disable first if you want to De-Install it.<p>',
+    'enabled'           => '<br' . XHTML . '>Plugin is installed and enabled.<br' . XHTML . '>Disable first if you want to De-Install it.<p>',
     'warning'           => 'Forum De-Install Warning',
-    'uploaderr'         => 'File Upload Error'
+    'uploaderr'         => 'File Upload Error',
+    'autotag_desc_forum' => '[forum: id alternate title] - Displays a link to a forum topic using the text \'hear\' as the title. An alternate title may be specified but is not required.'
 );
 
 
@@ -182,9 +182,9 @@ $LANG_GF01['OFFLINE']        = 'offline';
 $LANG_GF01['back2parent']    = 'Parent Topic';
 $LANG_GF01['forumname']      = '';   // Enter name here if you want it to show in the footer of the admin screens
 $LANG_GF01['category']       = 'Kategory: ';
-$LANG_GF01['loginreqview']   = '<B>Sorry you must %s register</A> or %s login </A> to use these forums</B>';
-$LANG_GF01['loginreqpost']   = '<B>Sorry you must register or login to post on these forums</B>';
-$LANG_GF01['searchresults']  = '<b></b> Your search for <b>%s</b> %s author returned <b>%s</b> results:</b><br><br>';
+$LANG_GF01['loginreqview']   = '<b>Sorry you must %s register</a> or %s login </a> to use these forums</b>';
+$LANG_GF01['loginreqpost']   = '<b>Sorry you must register or login to post on these forums</b>';
+$LANG_GF01['searchresults']  = '<b></b> Your search for <b>%s</b> %s author returned <b>%s</b> results:</b><br' . XHTML . '><br' . XHTML . '>';
 $LANG_GF01['feature_not_on'] = 'Feature not enabled';
 $LANG_GF01['nolastpostmsg']  = 'n/v';
 $LANG_GF01['no_one']         = 'No one.';
@@ -196,7 +196,7 @@ $LANG_GF01['DELALL_PM']      = 'Delete All';
 $LANG_GF01['DELOLDER_PM']    = 'Delete older';
 $LANG_GF01['members']        = 'Mitglieder';
 $LANG_GF01['save_sucess']    = 'Save Sucessful';
-$LANG_GF01['trademark']      = '<BR><CENTER><B>Geeklog Forum Project version 2.0</B> &copy; 2002</B></CENTER>';
+$LANG_GF01['trademark']      = '<br' . XHTML . '><center><b>Geeklog Forum Project version 2.0</b> &copy; 2002</b></center>';
 $LANG_GF01['back2top']       = 'Back to top';
 $LANG_GF01['POSTMODE']       = 'Post Mode:';
 $LANG_GF01['TEXTMODE']       = 'Text-Modus';
@@ -223,10 +223,14 @@ $LANG_GF01['PMLink']         = 'PM';
 $LANG_GF01['EmailLink']      = 'E-Mail';
 $LANG_GF01['FORUMSUBSCRIBE'] = 'Forum abonnieren';
 $LANG_GF01['FORUMUNSUBSCRIBE'] = 'Forum-Abo beenden';
+$LANG_GF01['SubscribeLink_TRUE']  = 'Abonnieren:Aktiviert';
+$LANG_GF01['SubscribeLink_FALSE'] = 'Abonnieren:Behinderte';
 $LANG_GF01['NEWTOPIC']       = 'Neues Thema';
 $LANG_GF01['POSTREPLY']      = 'Antwort schreiben';
 $LANG_GF01['SubscribeLink']  = 'Abonnieren';
 $LANG_GF01['unSubscribeLink'] = 'Abo beenden';
+$LANG_GF01['SubscribeLink_TRUE']  = 'Abonnieren:Aktiviert';
+$LANG_GF01['SubscribeLink_FALSE'] = 'Abonnieren:Behinderte';
 $LANG_GF01['FORUMSUBSCRIBE'] = 'Forum-Abo beenden';
 $LANG_GF01['NEWTOPIC']       = 'Neues Thema';
 $LANG_GF01['POSTREPLY']      = 'Antwort schreiben';
@@ -235,7 +239,7 @@ $LANG_GF01['TOP']            = 'Top of Post';
 $LANG_GF01['PRINTABLE']      = 'Druckfhige Version';
 $LANG_GF01['ForumProfile']   = 'Forum-Optionen';
 $LANG_GF01['USERPREFS']      = 'Forum-Einstellungen';
-$LANG_GF01['SPEEDLIMIT']     = '"Your last comment was %s seconds ago.<br>This site requires at least %s seconds between forum posts."';
+$LANG_GF01['SPEEDLIMIT']     = '"Your last comment was %s seconds ago.<br' . XHTML . '>This site requires at least %s seconds between forum posts."';
 $LANG_GF01['ACCESSERROR']    = 'ACCESS ERROR';
 $LANG_GF01['LEGEND']         = 'Legende';
 $LANG_GF01['ACTIONS']        = 'Aktionen';
@@ -254,6 +258,7 @@ $LANG_GF01['INDEXPAGE']      = 'Alle Foren';
 $LANG_GF01['FEATURE']        = 'Feature';
 $LANG_GF01['SETTING']        = 'Einstellung';
 $LANG_GF01['MARKALLREAD']    = 'Als gelesen markieren';
+$LANG_GF01['MSG_NO_CAT']     = 'No Categories or Forums Defined';
 
 // Language for bbcode toolbar
 $LANG_GF01['CODE']           = 'Code';
@@ -293,31 +298,31 @@ $LANG_GF01['p_help']         = "[img]http://image_url[/img] oder [img w=100 h=20
 $LANG_GF01['w_help']         = "URL: [url]http://url[/url] or [url=http://url]URL text[/url]";
 $LANG_GF01['a_help']         = "Alle offenen BBcode-Tags schlieen";
 $LANG_GF01['s_help']         = "Schriftfarbe: [color=red]text[/color]  Tipp: Du kannst auch color=#FF0000 benutzen";
-$LANG_GF01['f_help']         = "Schriftgre: [size=x-small]small text[/size]";
+$LANG_GF01['f_help']         = "Schriftgre: [size=7]small text[/size]";
 $LANG_GF01['h_help']         = 'Ausfhrliche Hilfe';
 
 
 $LANG_GF02['msg01']    = 'Sorry you must register to use these forums';
-$LANG_GF02['msg02']    = 'You should not be here!<br>Restricted access to this forum only';
+$LANG_GF02['msg02']    = 'You should not be here!<br' . XHTML . '>Restricted access to this forum only';
 $LANG_GF02['msg03']    = '';
 $LANG_GF02['msg04']    = '';
-$LANG_GF02['msg05']    = '<CENTER><I>Sorry, no topics have been created yet.</CENTER></I>';
+$LANG_GF02['msg05']    = '<center><em>Sorry, no topics have been created yet.</em></center>';
 $LANG_GF02['msg06']    = ' new posts since your last visit';
 $LANG_GF02['msg07']    = 'Wer ist online?';
-$LANG_GF02['msg08']    = '<br><B>Total Registered Users to Date:</B> %s';
-$LANG_GF02['msg09']    = '<br><B>Total Posts to Date:</B> %s <br>';
-$LANG_GF02['msg10']    = '<B>Total Topics to Date:</B> %s <br>';
+$LANG_GF02['msg08']    = '<br' . XHTML . '><b>Total Registered Users to Date:</b> %s';
+$LANG_GF02['msg09']    = '<br' . XHTML . '><b>Total Posts to Date:</b> %s <br' . XHTML . '>';
+$LANG_GF02['msg10']    = '<b>Total Topics to Date:</b> %s <br' . XHTML . '>';
 $LANG_GF02['msg11']    = 'Back to Forum Index';
 $LANG_GF02['msg12']    = 'Back to Main Homepage';
 $LANG_GF02['msg13']    = 'Registration Required, you currently must register or login to use this feature.';
-$LANG_GF02['msg14']    = 'Sorry, You have been banned from making entries.<br>';
-$LANG_GF02['msg15']    = 'If you feel this is an error, contact <A HREF="mailto:%s?subject=Forum IP Ban">Site Admin</A>.';
+$LANG_GF02['msg14']    = 'Sorry, You have been banned from making entries.<br' . XHTML . '>';
+$LANG_GF02['msg15']    = 'If you feel this is an error, contact <a href="mailto:%s?subject=Forum IP Ban">Site Admin</a>.';
 $LANG_GF02['msg16']    = 'These are the most popular posts, you may order them by views or replies.';
 $LANG_GF02['msg17']    = 'Message Edited, Your message has been edited sucessfully. Returning to your message.';
 $LANG_GF02['msg18']    = 'Fehler! Es wurden nicht alle bentigten Felder ausgefllt oder die Eintrge waren zu kurz.';
 $LANG_GF02['msg19']    = 'Dein Beitrag wurde verffentlicht.';
 $LANG_GF02['msg20']    = 'Reply Added, Your reply has been posted. Returning to Forum';
-$LANG_GF02['msg21']    = 'Sorry, you are unauthorized to do this. Please <a href="javascript:history.back()">Go Back</a> or <a href="%s/users.php?mode=login">Login</a><br><br>'; 
+$LANG_GF02['msg21']    = 'Sorry, you are unauthorized to do this. Please <a href="javascript:history.back()">Go Back</a> or <a href="%s/users.php?mode=login">Login</a><br' . XHTML . '><br' . XHTML . '>'; 
 $LANG_GF02['msg22']    = '- Neuer Beitrag im Forum';
 $LANG_GF02['msg23a']   = "Zum Thema '%s' hat %s eine Antwort geschrieben.\n\nDas Thema wurde von %s im %s-Forum begonnen. ";
 $LANG_GF02['msg23b']   = "Ein neues Thema, '%s', wurde von %s im %s-Forum auf der %s-Website begonnen. Du kannst den Beitrag hier lesen:\n%s/forum/viewtopic.php?showtopic=%s\n";
@@ -337,19 +342,19 @@ $LANG_GF02['msg35']    = 'Website:';
 $LANG_GF02['msg36']    = 'Stimmung:';
 $LANG_GF02['msg37']    = 'Message:';
 $LANG_GF02['msg38']    = 'Bei Antworten benachrichtigen ';
-$LANG_GF02['msg39']    = '<br>There are no topic reviews for this new topic.';
-$LANG_GF02['msg40']    = '<br>Sorry, but you have already asked to be notified of replies to this topic.<br><br>';
-$LANG_GF02['msg41']    = '<br>Thank you! You will now be notified of replies to topic %s .<br><br>';
+$LANG_GF02['msg39']    = '<br' . XHTML . '>There are no topic reviews for this new topic.';
+$LANG_GF02['msg40']    = '<br' . XHTML . '>Sorry, but you have already asked to be notified of replies to this topic.<br' . XHTML . '><br' . XHTML . '>';
+$LANG_GF02['msg41']    = '<br' . XHTML . '>Thank you! You will now be notified of replies to topic %s .<br' . XHTML . '><br' . XHTML . '>';
 $LANG_GF02['msg42']    = 'Thank you! You have now deleted notifications on this topic.';
 $LANG_GF02['msg43']    = 'Are you sure you want to delete this notification?.';
 $LANG_GF02['msg44']    = '<p style="margin:0px; padding:5px;">Du hast keine Benachrichtigungen aktiviert.</p>';
 $LANG_GF02['msg45']    = 'Search the Forum';
 $LANG_GF02['msg46']    = 'You can search the forum by entering keywords:';
 $LANG_GF02['msg47']    = 'You can also specify an author to search under:';
-$LANG_GF02['msg48']    = '<br>The Chatterblock Plugin needs to be installed first.';
+$LANG_GF02['msg48']    = '<br' . XHTML . '>The Chatterblock Plugin needs to be installed first.';
 $LANG_GF02['msg49']    = '(%s Mal gelesen) ';
 $LANG_GF02['msg50']    = 'Signatur n/v';
-$LANG_GF02['msg51']    = "%s\n\n<br>[Edited at %s by %s]";
+$LANG_GF02['msg51']    = "%s\n\n<br" . XHTML . ">[Edited at %s by %s]";
 $LANG_GF02['msg52']    = 'Confirmed:';
 $LANG_GF02['msg53']    = 'Returning to topic..';
 $LANG_GF02['msg54']    = 'Post Edited.';
@@ -363,26 +368,26 @@ $LANG_GF02['msg61']    = 'Wichtiges Thema';
 $LANG_GF02['msg62']    = 'Benachrichtigung bei neuen Beitrgen';
 $LANG_GF02['msg63']    = 'Profil';
 $LANG_GF02['msg64']    = 'Are you sure you want to delete topic %s titled: %s ?';
-$LANG_GF02['msg65']    = '<br>This is a parent topic, so all replies posted to it will also be deleted.';
+$LANG_GF02['msg65']    = '<br' . XHTML . '>This is a parent topic, so all replies posted to it will also be deleted.';
 $LANG_GF02['msg66']    = 'Confirm Delete Post';
 $LANG_GF02['msg67']    = 'Edit Forum Post';
 $LANG_GF02['msg68']    = 'Note: BE CAREFUL WHEN YOU BAN, only admins have the rights to unban someone.';
 $LANG_GF02['msg69']    = 'Do you really want to ban the ip address: %s?';
 $LANG_GF02['msg70']    = 'Confirm Ban';
-$LANG_GF02['msg71']    = 'No function selected, choose a post and then a moderator function.<br>Note: You must be a moderator to perform these functions.';
+$LANG_GF02['msg71']    = 'No function selected, choose a post and then a moderator function.<br' . XHTML . '>Note: You must be a moderator to perform these functions.';
 $LANG_GF02['msg72']    = 'Warning, you do not have rights to perform this moderation function.';
 $LANG_GF02['msg74']    = 'Latest %s Forum Posts';
 $LANG_GF02['msg75']    = 'Top %s Topics By Views';
 $LANG_GF02['msg76']    = 'Top %s Topics By Posts';
-$LANG_GF02['msg77']    = '<br><p style="padding-left:10px;">You should not be here!<br>Restricted access to this forum only.<p />';
-$LANG_GF02['msg78']    = '<br>You should not be here!<br>Invalid Forum.';
+$LANG_GF02['msg77']    = '<br' . XHTML . '><p style="padding-left:10px;">You should not be here!<br' . XHTML . '>Restricted access to this forum only.</p>';
+$LANG_GF02['msg78']    = '<br' . XHTML . '>You should not be here!<br' . XHTML . '>Invalid Forum.';
 $LANG_GF02['msg81']    = '- Topic Edit Notification';
-$LANG_GF02['msg82']    = '<p>Your message "%s" has been edited by the moderator %s.<p>';
-$LANG_GF02['msg83']    = '<br><br>You need to be signed in to use this forum feature.<p />';
+$LANG_GF02['msg82']    = '<p>Your message "%s" has been edited by the moderator %s.</p>';
+$LANG_GF02['msg83']    = '<br' . XHTML . '><br' . XHTML . '><p>You need to be signed in to use this forum feature.</p>';
 $LANG_GF02['msg84']    = 'Alle Themen als gelesen markieren';
 $LANG_GF02['msg85']    = 'Seite:';
 $LANG_GF02['msg86']    = '&nbsp;Letzte %s Beitrge&nbsp;';
-$LANG_GF02['msg87']    = '<br>Warning: This topic has been locked by the moderator.<br>No additional posts are permitted';
+$LANG_GF02['msg87']    = '<br' . XHTML . '>Warning: This topic has been locked by the moderator.<br' . XHTML . '>No additional posts are permitted';
 $LANG_GF02['msg88']    = 'Mitglieder';
 $LANG_GF02['msg88b']   = 'Nur im Forum aktive Mitglieder';
 $LANG_GF02['msg89']    = 'Meine Benachrichtigungen';
@@ -448,10 +453,10 @@ $LANG_GF02['msg158']   = 'Last 10 Forum posts by ';
 $LANG_GF02['msg159']   = 'Are you sure you want to DELETE these selected Moderator records?';
 $LANG_GF02['msg160']   = 'View last page of topic';
 $LANG_GF02['msg161']   = 'Return to members list';
-$LANG_GF02['msg162']   = 'To return to the forum index now click <a href="%s">here</a><br><p />Default is to  return automatically to view your post.<br>If you do not wish to wait, click <a href="%s">here</a> now.';
+$LANG_GF02['msg162']   = 'To return to the forum index now click <a href="%s">here</a><br' . XHTML . '>Default is to return automatically to view your post.<br' . XHTML . '>If you do not wish to wait, click <a href="%s">here</a> now.';
 $LANG_GF02['msg163']   = 'Post moved';
 $LANG_GF02['msg164']   = 'Mark all Categories and Topics Read';
-$LANG_GF02['msg165']   = 'ERROR<p />Matching <b>QUOTE</b> tag missing. Unable to format message.<p />';
+$LANG_GF02['msg165']   = '<p>ERROR: Matching <b>QUOTE</b> tag missing. Unable to format message.</p>';
 $LANG_GF02['msg166']   = 'ERROR: Invalid topic or Topic not found';
 $LANG_GF02['msg167']   = 'Notification Option';
 $LANG_GF02['msg168']   = 'Setting of No will disable email notifictions';
@@ -509,8 +514,8 @@ $LANG_GF03 = array (
     'stick'             => 'Wichtiges Thema',
     'unstick'           => 'Normales Thema',
     'movetopic'         => 'Thema verschieben',
-    'movetopicmsg'      => '<br>Topic to be moved: "<b>%s</b>"',
-    'splittopicmsg'     => '<br>Create a new Topic with this post: "<b>%s</b>"<br><em>By:</em>&nbsp;%s&nbsp <em>On:</em>&nbsp;%s',
+    'movetopicmsg'      => '<br' . XHTML . '>Topic to be moved: "<b>%s</b>"',
+    'splittopicmsg'     => '<br' . XHTML . '>Create a new Topic with this post: "<b>%s</b>"<br' . XHTML . '><em>By:</em>&nbsp;%s&nbsp <em>On:</em>&nbsp;%s',
     'selectforum'       => 'Select new forum:',
     'lockedpost'        => 'Add Reply Post',
     'splitheading'      => 'Split thread option:',
@@ -660,7 +665,7 @@ $LANG_GF92 = array (
     'allownotify'        => 'Allow Notification',
     'allownotifydscp'    => 'Do you want to allow people to be notified?',
     'defaultmode'        => 'Default Post Mode',
-    'defaultmodedscp'    => 'Enable HTML Mode as default - set to Yes.<br>Enable Text mode as default (safest) - set to No',
+    'defaultmodedscp'    => 'Enable HTML Mode as default - set to Yes.<br' . XHTML . '>Enable Text mode as default (safest) - set to No',
     'cbsettings'         => 'Centerblock Settings',
     'cbenable'           => 'Enable Centerblock',
     'cbenabledscp'       => '',
@@ -758,7 +763,7 @@ $LANG_GF93 = array (
     'ModBan'             => 'Ban',
     'addmoderator'       => "Add Record",
     'delmoderator'       => " Delete\nSelected",
-    'moderatorwarning'   => '<b>Warning: No Forums Defined</b><br><br>Setup Forum Categories and Add at least 1 forum<br>before attempting to add Modertators',
+    'moderatorwarning'   => '<b>Warning: No Forums Defined</b><br' . XHTML . '><br' . XHTML . '>Setup Forum Categories and Add at least 1 forum<br' . XHTML . '>before attempting to add Modertators',
     'private'           => 'Private Forum',
     'filtertitle'       => 'Select Moderator records to view',
     'addmessage'        => 'Add new Moderator',
