@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.7                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-upgrade.php                                                           |
 // |                                                                           |
 // | Functions needed to perform a database update.                            |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2010 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Matt West         - matt.danger.west AT gmail DOT com            |
 // |          Dirk Haun         - dirk AT haun-online DOT de                   |
@@ -407,42 +407,7 @@ function INST_doDatabaseUpgrades($current_gl_version)
             $config->set('rdf_file', $html_path . 'backend/geeklog.rss');
             $config->set('path_pear', $_CONF['path_system'] . 'pear/');
 
-
-            if (INST_pluginExists('calendar')) {
-                $check = upgrade_CalendarPlugin();
-                if (!$check) {
-                    echo "Error updating the calendar";
-                    return false;
-                }
-            }
-            if (INST_pluginExists('polls')) {
-                $check = upgrade_PollsPlugin();
-                if (!$check) {
-                    echo "Error updating the polls";
-                    return false;
-                }
-            }
-            if (INST_pluginExists('staticpages')) {
-                $check = upgrade_StaticpagesPlugin();
-                if (!$check) {
-                    echo "Error updating the staticpages";
-                    return false;
-                }
-            }
-            if (INST_pluginExists('links')) {
-                $check = upgrade_LinksPlugin();
-                if (!$check) {
-                    echo "Error updating the links";
-                    return false;
-                }
-            }
-            if (INST_pluginExists('spamx')) {
-                $check = upgrade_SpamXPlugin();
-                if (!$check) {
-                    echo "Error updating the spamx";
-                    return false;
-                }
-            }
+            // core plugin updates are done in the plugins themselves
 
             $current_gl_version = '1.5.0';
             $_SQL = '';
@@ -457,9 +422,7 @@ function INST_doDatabaseUpgrades($current_gl_version)
             break;
 
         case '1.5.1':
-            require_once $_CONF['path'] . 'sql/updates/' . $_DB_dbms . '_1.5.1_to_1.5.2.php';
-            INST_updateDB($_SQL);
-
+            // there were no core database changes in 1.5.2
             $current_gl_version = '1.5.2';
             $_SQL = '';
             break;
@@ -497,7 +460,28 @@ function INST_doDatabaseUpgrades($current_gl_version)
             $current_gl_version = '1.7.0';
             $_SQL = '';
             break;
+
+        case '1.7.0':
+            $current_gl_version = '1.7.2'; // skip ahead
+            $_SQL = '';
+            break;
+
+        case '1.7.1':
+            // there were no database changes in 1.7.1
+        case '1.7.2':
+            require_once $_CONF['path'] . 'sql/updates/' . $_DB_dbms . '_1.7.2_to_1.8.0.php';
+            INST_updateDB($_SQL);
+
+            update_ConfValuesFor180();
+
+            update_ConfigSecurityFor180();
             
+            update_UsersFor180();
+
+            $current_gl_version = '1.8.0';
+            $_SQL = '';
+            break;
+
         default:
             $done = true;
         }
@@ -643,6 +627,7 @@ function INST_setDefaultCharset($siteconfig_path, $charset)
 {
     $result = true;
 
+    clearstatcache();
     $siteconfig_file = fopen($siteconfig_path, 'rb');
     $siteconfig_data = fread($siteconfig_file, filesize($siteconfig_path));
     fclose($siteconfig_file);
