@@ -132,15 +132,10 @@ if (forum_modPermission($forum,$_USER['uid'])) {
             DB_query("DELETE FROM {$_TABLES['gf_log']} WHERE topic='$topicparent'");
 
             if ($top == 'yes') {
-//                $link = "{$_CONF['site_url']}/forum/index.php?forum=$forum";
-//                $display .= forum_statusMessage($LANG_GF02['msg55'],$link,$LANG_GF02['msg55'],true,$forum);
                 $display = COM_refresh($_CONF['site_url'] . "/forum/index.php?msg=3&amp;forum=$forum");
             } else {
-//                $link = "{$_CONF['site_url']}/forum/viewtopic.php?showtopic=$msgpid";
-//                $display .= forum_statusMessage($LANG_GF02['msg55'],$link,$LANG_GF02['msg55'],true,$forum);
                 $display = COM_refresh($_CONF['site_url'] . "/forum/viewtopic.php?msg=5&amp;showtopic=$msgpid");
             }
-//            $display .= gf_siteFooter();
             echo $display;
             exit();
         }
@@ -153,10 +148,7 @@ if (forum_modPermission($forum,$_USER['uid'])) {
         } else {
             $hostip = COM_applyFilter($_POST['hostip']);
             DB_query("INSERT INTO {$_TABLES['gf_banned_ip']} (host_ip) VALUES ('$hostip')");
-//            $link = "{$_CONF['site_url']}/forum/viewtopic.php?showtopic=$fortopicid";
-//            $display .= forum_statusMessage($LANG_GF02['msg56'],$link,$LANG_GF02['msg56']);
             $display = COM_refresh($_CONF['site_url'] . "/forum/viewtopic.php?msg=6&amp;showtopic=$fortopicid");
-//            $display .= gf_siteFooter();
             echo $display;
             exit();
         }
@@ -224,8 +216,6 @@ if (forum_modPermission($forum,$_USER['uid'])) {
                     DB_query("UPDATE {$_TABLES['gf_forums']} SET topic_count=topic_count+1, post_count=post_count+$numreplies WHERE forum_id=$newforumid");
                     DB_query("UPDATE {$_TABLES['gf_forums']} SET topic_count=topic_count-1, post_count=post_count-$numreplies WHERE forum_id=$forum");
                 }
-//                $link = "{$_CONF['site_url']}/forum/viewtopic.php?showtopic=$moveid";
-//                $display .= forum_statusMessage(sprintf($LANG_GF02['msg183'],$movetoforum),$link,$LANG_GF02['msg183']);
                 $display = COM_refresh($_CONF['site_url'] . "/forum/viewtopic.php?msg=7&amp;showtopic=$moveid");
 
             } else {  // Move complete topic
@@ -250,11 +240,8 @@ if (forum_modPermission($forum,$_USER['uid'])) {
 
                 // Remove any lastviewed records in the log so that the new updated topic indicator will appear
                 DB_query("DELETE FROM {$_TABLES['gf_log']} WHERE topic='$moveid'");
-//                $link = "{$_CONF['site_url']}/forum/viewtopic.php?showtopic=$moveid";
-//                $display .= forum_statusMessage($LANG_GF02['msg163'],$link,$LANG_GF02['msg163']);
                 $display = COM_refresh($_CONF['site_url'] . "/forum/viewtopic.php?msg=8&amp;showtopic=$moveid");
             }
-//            $display .= gf_siteFooter();
             echo $display;
             exit();
 
@@ -362,7 +349,7 @@ if (forum_modPermission($forum,$_USER['uid'])) {
         $ip_address = $forumpostipnum['ip'];
         if (!empty($_CONF['ip_lookup'])) {
             $iplookup = str_replace('*', $ip_address, $_CONF['ip_lookup']);
-            $ip_address = '<a href="' . $iplookup . '">' . $ip_address . '</a>';
+            $ip_address = COM_createLink($ip_address, $iplookup);
         }
         $alertmessage .= sprintf($LANG_GF02['msg69'], $ip_address) . '</p>';
 
